Comparisons of subsegments of the Y chromosome in human and chimp
chrY_subseg.RdA subsegment of the Y chromosome in Homo sapiens and Pan troglodytes, to illustrate support for exons and introns.
Usage
data(chrY_subseg)Format
chrY_subseg, a list of two data frame lists, representing the Y
segment in the two species and a comparison between them:
dna_segsA list of 2
dna_segobjects, containing 3 genes each. Each exon and intron is a seperate feature (row) in thedna_seg.comparisonA list containing 1
comparisonobject.
Examples
data(chrY_subseg)
plot_gene_map(chrY_subseg$dna_segs, chrY_subseg$comparison,
dna_seg_scale = TRUE, scale = FALSE)